==> stargazer_5.1.tar.gz: stargazer/man/stargazer_models.Rd <==
\name{stargazer_models}
\alias{stargazer models}

%- Also NEED an '\alias' for EACH other topic documented here.
\title{stargazer: list of supported objects}
%%  ~~function to do ... ~~
\description{
%%  ~~ A concise (1-5 lines) description of what the function does. ~~
This page summarizes the models that \code{stargazer} supports. Please note that I am always looking for comments and suggestions. Do not hesitate to contact me at hlavac [at] fas.harvard.edu.
}

\section{Supported objects}{
The package name is indicated in bold and is followed by a list of functions/object types.\cr
\cr

\bold{AER}: \cr
- \code{ivreg}\cr
- \code{tobit}\cr
\cr
\bold{betareg}: \cr
- \code{betareg}\cr
\cr
\bold{brglm}: \cr
- \code{brglm}\cr
\cr
\bold{dynlm}: \cr
- \code{dynlm}\cr
\cr
\bold{eha}:\cr
- \code{aftreg}\cr
- \code{coxreg}\cr
- \code{mlreg}\cr
- \code{phreg}\cr
- \code{weibreg}\cr
\cr
\bold{erer}: \cr
- \code{maBina}\cr
\cr
\bold{ergm}: \cr
- \code{ergm}\cr
\cr
\bold{gee}:\cr
- \code{gee}\cr
\cr
\bold{glmx}:\cr
- \code{hetglm}\cr
\cr
\bold{gmm}:\cr
- \code{gmm}\cr
\cr
\bold{lfe}:\cr
- \code{felm}\cr
\cr
\bold{lme4}:\cr
- \code{glmer}\cr
- \code{lmer}\cr
- \code{nlmer}\cr
\cr
\bold{lmtest}: \cr
- \code{coeftest}\cr
\cr
\bold{MASS}:\cr
- \code{polr}\cr
- \code{rlm}\cr
- \code{survreg}\cr
\cr
\bold{mclogit}: \cr
- \code{mclogit}\cr
\cr
\bold{mgcv}:\cr
- \code{gam}\cr
\cr
\bold{mlogit}: \cr
- \code{mlogit}\cr
\cr
\bold{nlme}:\cr
- \code{gls}\cr
\cr
\bold{nnet}: \cr
- \code{multinom}\cr
\cr
\bold{ordinal}: \cr
- \code{clm}\cr
\cr
\bold{plm}:\cr
- \code{plm}\cr
- \code{pmg}\cr
\cr
\bold{pscl}:\cr
- \code{hurdle}\cr
- \code{zeroinfl}\cr
\cr
\bold{rms}:\cr
- \code{bj}\cr
- \code{cph}\cr
- \code{Glm}\cr
- \code{Gls}\cr
- \code{lrm}\cr
- \code{ols}\cr
- \code{psm}\cr
- \code{Rq}\cr
\cr
\bold{relevent}: \cr
- \code{rem.dyad}\cr
\cr
\bold{rq}:\cr
- \code{quantreg}\cr
\cr
\bold{robustbase}: \cr
- \code{lmrob}\cr
\cr
\bold{sampleSelection}:\cr
- \code{binaryChoice}\cr
- \code{heckit}\cr
- \code{probit}\cr
- \code{selection}\cr
\cr
\bold{spdep}:\cr
- \code{errorsarlm}\cr
- \code{largarlm}\cr
\cr
\bold{stats}:\cr
- \code{glm}\cr
- \code{lm}\cr
\cr
\bold{survey}:\cr
- \code{svyglm}\cr
\cr
\bold{survival}:\cr
- \code{coxph}\cr
- \code{clogit}\cr
- \code{survreg}\cr
\cr
\bold{Zelig}:\cr
- the implementation of the above models 
- \code{relogit}\cr
- \code{cloglog.net}\cr
- \code{gamma.net}\cr
- \code{probit.net}\cr
- \code{logit.net}\cr
\cr

}

% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ package }
\keyword{ models }
\keyword{ regression }
\keyword{ nonlinear }
\keyword{ univar }
\keyword{ interface }
\keyword{ programming }
\keyword{ IO }% __ONLY ONE__ keyword per line

==> stargazer_5.2.tar.gz: stargazer/man/stargazer_models.Rd <==
\name{stargazer_models}
\alias{stargazer models}

%- Also NEED an '\alias' for EACH other topic documented here.
\title{stargazer: list of supported objects}
%%  ~~function to do ... ~~
\description{
%%  ~~ A concise (1-5 lines) description of what the function does. ~~
This page summarizes the models that \code{stargazer} supports. Please note that I am always looking for comments and suggestions. Do not hesitate to contact me at hlavac [at] fas.harvard.edu.
}

\section{Supported objects}{
The package name is indicated in bold and is followed by a list of functions/object types.\cr
\cr

\bold{AER}: \cr
- \code{ivreg}\cr
- \code{tobit}\cr
\cr
\bold{betareg}: \cr
- \code{betareg}\cr
\cr
\bold{brglm}: \cr
- \code{brglm}\cr
\cr
\bold{censReg}:\cr
- \code{censReg}\cr
\cr
\bold{dynlm}: \cr
- \code{dynlm}\cr
\cr
\bold{eha}:\cr
- \code{aftreg}\cr
- \code{coxreg}\cr
- \code{mlreg}\cr
- \code{phreg}\cr
- \code{weibreg}\cr
\cr
\bold{erer}: \cr
- \code{maBina}\cr
\cr
\bold{ergm}: \cr
- \code{ergm}\cr
\cr
\bold{fGarch}:\cr
- \code{garchFit}\cr
\cr
\bold{gee}:\cr
- \code{gee}\cr
\cr
\bold{glmx}:\cr
- \code{hetglm}\cr
\cr
\bold{gmm}:\cr
- \code{gmm}\cr
\cr
\bold{lfe}:\cr
- \code{felm}\cr
\cr
\bold{lme4}:\cr
- \code{glmer}\cr
- \code{lmer}\cr
- \code{nlmer}\cr
\cr
\bold{lmtest}: \cr
- \code{coeftest}\cr
\cr
\bold{MASS}:\cr
- \code{polr}\cr
- \code{rlm}\cr
- \code{survreg}\cr
\cr
\bold{mclogit}: \cr
- \code{mclogit}\cr
\cr
\bold{mgcv}:\cr
- \code{gam}\cr
\cr
\bold{mlogit}: \cr
- \code{mlogit}\cr
\cr
\bold{mnlogit}: \cr
- \code{mnlogit}\cr
\cr
\bold{nlme}:\cr
- \code{gls}\cr
- \code{lme}\cr
- \code{nlme}\cr
\cr
\bold{nnet}: \cr
- \code{multinom}\cr
\cr
\bold{ordinal}: \cr
- \code{clm}\cr
\cr
\bold{plm}:\cr
- \code{pgmm}\cr
- \code{plm}\cr
- \code{pmg}\cr
\cr
\bold{pscl}:\cr
- \code{hurdle}\cr
- \code{zeroinfl}\cr
\cr
\bold{rms}:\cr
- \code{bj}\cr
- \code{cph}\cr
- \code{Glm}\cr
- \code{Gls}\cr
- \code{lrm}\cr
- \code{ols}\cr
- \code{psm}\cr
- \code{Rq}\cr
\cr
\bold{relevent}: \cr
- \code{rem.dyad}\cr
\cr
\bold{rq}:\cr
- \code{quantreg}\cr
\cr
\bold{robustbase}: \cr
- \code{glmrob}\cr
- \code{lmrob}\cr
\cr
\bold{sampleSelection}:\cr
- \code{binaryChoice}\cr
- \code{heckit}\cr
- \code{probit}\cr
- \code{selection}\cr
\cr
\bold{spdep}:\cr
- \code{errorsarlm}\cr
- \code{largarlm}\cr
\cr
\bold{stats}:\cr
- \code{arima}\cr
- \code{glm}\cr
- \code{lm}\cr
\cr
\bold{survey}:\cr
- \code{svyglm}\cr
\cr
\bold{survival}:\cr
- \code{coxph}\cr
- \code{clogit}\cr
- \code{survreg}\cr
\cr
\bold{Zelig}:\cr
- the implementation of the above models \cr
- \code{relogit}\cr
- \code{cloglog.net}\cr
- \code{gamma.net}\cr
- \code{probit.net}\cr
- \code{logit.net}\cr
\cr


}

% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ package }
\keyword{ models }
\keyword{ regression }
\keyword{ nonlinear }
\keyword{ univar }
\keyword{ interface }
\keyword{ programming }
\keyword{ IO }% __ONLY ONE__ keyword per line
